@@ -69,7 +69,7 @@ class SearchRevisionTicketOp(hook.DataOperationMixIn,
                                 break
 
 class RevisionAdded(hook.Hook):
-    __regid__ = 'trackervcs.revistion-to-ticket-state'
+    __regid__ = 'trackervcs.revision-to-ticket-state'
     __select__ = hook.Hook.__select__ & is_instance('Revision')
     events = ('after_add_entity',)
     category = 'autoset'
@@ -89,7 +89,7 @@ class SetSourceRepositoryOp(hook.Operation):
             self.project.set_relations(source_repository=self.projectenv.repository)
 
 class ApycotEnvironmentAdded(hook.Hook):
-    __regid__ = 'trackervcs.revistion-to-ticket-state'
+    __regid__ = 'trackervcs.add-source-repository'
     __select__ = hook.Hook.__select__ & hook.match_rtype('has_apycot_environment')
     events = ('after_add_relation',)
     category = 'autoset'
