@@ -52,13 +52,6 @@ class ProjectPatchesTab(EntityView):
             'vcreview.repository.patches', w=self.w)
 
 
-class SourceRepositoryIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
-    __select__ = is_instance('Repository') & score_entity(lambda x: x.reverse_source_repository)
-
-    def parent_entity(self):
-        return self.entity.reverse_source_repository[0]
-
-
 class PatchRepositoryIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
     __select__ = is_instance('Repository') & score_entity(lambda x: x.patchrepo_of)
 
@@ -93,18 +86,19 @@ def registration_callback(vreg):
     # overridde vcreview summary tables to include patch's ticket and ticket's
     # version
     vcreview_startup.AllActivePatches.rql = (
-        'Any P,PO,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
+        'Any P,PO,P,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
         'ORDERBY RT,PB,PO WHERE P originator PO, P branch PB, P in_state PS, '
         'TR? wf_info_for P, P patch_repository R, R title RT, '
         'PS name %s, '
         'P patch_ticket T?, T done_in V?')
     vcreview_startup.UserWorkList.rql = (
-        'Any P,PO,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
+        'Any P,PO,P,P,PB,PS,COUNT(TR),R,T,V GROUPBY R,P,PO,PB,PS,T,V '
         'ORDERBY RT,PB,PO WHERE P originator PO, P branch PB, P in_state PS,'
         'TR? wf_info_for P, P patch_repository R, R title RT, U eid %(u)s, '
         'EXISTS(PS name "pending-review" AND P patch_reviewer U) '
-        'OR EXISTS(PS name IN ("reviewed", "deleted") AND (EXISTS(R repository_committer U) '
-        'OR EXISTS(U in_group G, G name "committers"))), '
+        'OR EXISTS(PS name "reviewed" AND P patch_committer U) '
+        'OR (EXISTS(PS name IN ("reviewed", "deleted") AND NOT EXISTS(P patch_committer V) '
+        '    AND (EXISTS(R repository_committer U) OR EXISTS(U in_group G, G name "committers"))))'
         'P patch_ticket T?, T done_in V?')
     vcreview_primary.RepositoryPatchesTable.rql = (
         'Any P,PO,P,PB,PS,COUNT(TR),T,V GROUPBY P,PO,PB,PS,T,V WHERE '
